check

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package check provides various configuration and health checks that can be run for move operations.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunChecks

func RunChecks(ctx context.Context, r Resources, logger *slog.Logger, scope ScopeFlag) error

RunChecks runs all checks that are registered for the given scope

Types

type Resources

type Resources struct {
	SourceDB       *sql.DB
	SourceConfig   *mysql.Config
	Targets        []applier.Target
	SourceTables   []*table.TableInfo
	CreateSentinel bool
	// For PreRun checks (before DB connections established)
	SourceDSN string
	TargetDSN string
}

Resources contains the resources needed for move checks

type ScopeFlag

type ScopeFlag uint8

ScopeFlag scopes a check

const (
	ScopeNone ScopeFlag = iota
	ScopePreRun
	ScopePreflight
	ScopePostSetup
	ScopeResume
)

Jump to